# Investment Taxonomy

Source of truth: `dev-health-ops/investment_taxonomy.py`

## Themes
- `feature_delivery"`
- `maintenance"`
- `operational"`
- `quality"`
- `risk"`

## Subcategories (by theme)
### `feature_delivery"`


### `maintenance"`


### `operational"`


### `quality"`


### `risk"`



## Guarantees
- Subcategory keys are canonical and fixed.
- Theme roll-up is deterministic via `theme_of(subcategory)`.
